A simple interactive device for adjusting a curve. Given a set of points, the curve is plotted and may then be adjusted interactively by clicking on any of the points, one at a time, and clicking again at its intended new position.
adjust_curve(
x,
y = NULL,
...,
plotit = TRUE,
curve = open_curve,
ccolour = "#DF536B",
pcolour = "#2297E6"
)Any means of specifying points in the plane, as accepted by xy.coords()
additional arguments past on to curve()
logical: should the curve be plotted (TRUE) or can it be assumed the points are already on the display (FALSE)?
One of the curve type functions of this package
character string: colour for the curve in the plot
character string: colour for the points in the plot
The adjusted points which define the adjusted curve